mathtools.Ratio
===============

.. inheritance-diagram:: abjad.tools.mathtools.Ratio.Ratio.Ratio
   :private-bases:

.. autoclass:: abjad.tools.mathtools.Ratio.Ratio.Ratio

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.mathtools.Ratio.Ratio.Ratio.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Methods
-------

.. automethod:: abjad.tools.mathtools.Ratio.Ratio.Ratio.count

    Inherited from :py:class:`__builtin__.tuple`

.. automethod:: abjad.tools.mathtools.Ratio.Ratio.Ratio.index

    Inherited from :py:class:`__builtin__.tuple`

Special Methods
---------------

.. automethod:: abjad.tools.mathtools.Ratio.Ratio.Ratio.__add__

    Inherited from :py:class:`__builtin__.tuple`

.. automethod:: abjad.tools.mathtools.Ratio.Ratio.Ratio.__contains__

    Inherited from :py:class:`__builtin__.tuple`

.. automethod:: abjad.tools.mathtools.Ratio.Ratio.Ratio.__eq__

.. automethod:: abjad.tools.mathtools.Ratio.Ratio.Ratio.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.mathtools.Ratio.Ratio.Ratio.__getitem__

    Inherited from :py:class:`__builtin__.tuple`

.. automethod:: abjad.tools.mathtools.Ratio.Ratio.Ratio.__getslice__

    Inherited from :py:class:`__builtin__.tuple`

.. automethod:: abjad.tools.mathtools.Ratio.Ratio.Ratio.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.mathtools.Ratio.Ratio.Ratio.__hash__

    Inherited from :py:class:`__builtin__.tuple`

.. automethod:: abjad.tools.mathtools.Ratio.Ratio.Ratio.__iter__

    Inherited from :py:class:`__builtin__.tuple`

.. automethod:: abjad.tools.mathtools.Ratio.Ratio.Ratio.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.mathtools.Ratio.Ratio.Ratio.__len__

    Inherited from :py:class:`__builtin__.tuple`

.. automethod:: abjad.tools.mathtools.Ratio.Ratio.Ratio.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.mathtools.Ratio.Ratio.Ratio.__mul__

    Inherited from :py:class:`__builtin__.tuple`

.. automethod:: abjad.tools.mathtools.Ratio.Ratio.Ratio.__ne__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.mathtools.Ratio.Ratio.Ratio.__repr__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.mathtools.Ratio.Ratio.Ratio.__rmul__

    Inherited from :py:class:`__builtin__.tuple`
